% Fonction renvoyant la matrice de rigidit d'un lment rectangulaire avec
% fonctions d'interpolation du champ de dplacement linaire.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simon 21/12/2005
%
% Nom du fichier : K_elem.m
%
% Description : Cette fonction renvoie la matrice de rigidit d'un lment
% rectangulaire homogne pour la mthode des lments finis.
%
% Matriau :
% E : module d'Young
% nu : Coeff de Poisson
%
%
% Geometrie :
%
% noeud 4 %%%%%%%%%%%%%%%%% noeud 3
%                                 %
%                                 %
%                                 %
%                                 % longueur b
%                                 %
%                                 %
% noeud 1 %%%%%%%%%%%%%%%%% noeud 2
%            longueur a
%
% Origine lors de l'intgration sur le volume pour le construction de Ke au
% noeud 1.
% Matrice Ke construite sur Xcas, logiciel dvelopp par l'UJF, comparable
%  Maple.
% Ke est alors identique  la matrice Ke de Jean-Louis Batoz dans
% "Modlisation des structures par EF" p 257 sauf pour le terme (2,8) ou le
% deuxime (-) est en fait un (+).
% Ici, ce terme est corrig.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function sortie=K_elem(E,nu,a,b,alpha)

% Variables du livre de Batoz :
% alpha = 1; % '1' = dformations planes; '0' en contraintes planes
G=E/(2*(1+nu));
H1=2*G*(1-alpha*nu)/(1-nu-alpha*nu);
H2=nu*H1/(1-alpha*nu);
c=H2+G;
d=H2-G;

K_batoz=zeros(8,8);

% Diagonale :
K_batoz(1,1)=4*H1/a^2+4*G/b^2;
K_batoz(2,2)=4*H1/b^2+4*G/a^2;
K_batoz(3,3)=4*H1/a^2+4*G/b^2;
K_batoz(4,4)=4*H1/b^2+4*G/a^2;
K_batoz(5,5)=4*H1/a^2+4*G/b^2;
K_batoz(6,6)=4*H1/b^2+4*G/a^2;
K_batoz(7,7)=4*H1/a^2+4*G/b^2;
K_batoz(8,8)=4*H1/b^2+4*G/a^2;

% 1ere ligne :
K_batoz(1,2)=3*c/(a*b);
K_batoz(1,3)=-4*H1/a^2+2*G/b^2;
K_batoz(1,4)=3*d/(a*b);
K_batoz(1,5)=-2*H1/a^2-2*G/b^2;
K_batoz(1,6)=-3*c/(a*b);
K_batoz(1,7)=2*H1/a^2-4*G/b^2;
K_batoz(1,8)=-3*d/(a*b);

% 2ieme ligne :             
K_batoz(2,3)=-3*d/(a*b);
K_batoz(2,4)=2*H1/b^2-4*G/a^2;
K_batoz(2,5)=-3*c/(a*b);
K_batoz(2,6)=-2*H1/b^2-2*G/a^2;
K_batoz(2,7)=3*d/(a*b);
K_batoz(2,8)=-4*H1/b^2+2*G/a^2;

% 3ieme ligne :
K_batoz(3,4)=-3*c/(a*b);
K_batoz(3,5)=2*H1/a^2-4*G/b^2;
K_batoz(3,6)=3*d/(a*b);
K_batoz(3,7)=-2*H1/a^2-2*G/b^2;
K_batoz(3,8)=3*c/(a*b);

% 4ieme ligne :
K_batoz(4,5)=-3*d/(a*b);
K_batoz(4,6)=-4*H1/b^2+2*G/a^2;
K_batoz(4,7)=3*c/(a*b);
K_batoz(4,8)=-2*H1/b^2-2*G/a^2;

% 5ieme ligne :
K_batoz(5,6)=3*c/(a*b);
K_batoz(5,7)=-4*H1/a^2+2*G/b^2;
K_batoz(5,8)=3*d/(a*b);

% 6ieme ligne :
K_batoz(6,7)=-3*d/(a*b);
K_batoz(6,8)=2*H1/b^2-4*G/a^2;

% 7ieme ligne :
K_batoz(7,8)=-3*c/(a*b);

% 8ieme ligne deja ecrite (diagonale)...

% Remplissage de la partie symtrique de la matrice :
% On prend la diagonale de K_batoz :
Diago_K_batoz=diag(diag(K_batoz));
% On soustrait cette diagonale  K_batoz :
K_batoz=K_batoz-Diago_K_batoz;
% On ajoute la transpose de K_batoz  elle-meme + la diagonale stokee auparavant :
K_batoz=K_batoz'+K_batoz+Diago_K_batoz;

% Matrice K_elem :
sortie=a*b/12*K_batoz;
